/*
 * This is a polling timer that relies on the Arduino mills() function
 * 
 * When constructed without arguments, the timer is not running and will never become lapsed.
 * Calling the constructor with a 0 will make it lapsed immediately.
 * Constructing or set with a non zero argument causes the timer to lapse that many milliseconds
 * in the future, plus up to 1 millisecond alignment error.
 */
class Timer {
  public:
    Timer() { }

    Timer(unsigned long nrMillisecondsHence) {
      set(nrMillisecondsHence);
    }

    void set(unsigned long nrMillisecondsHence) {
      alarmTime = millis() + nrMillisecondsHence;
      isRunning = true;
    }

    void clear() {
      isRunning = false;
    }

    bool lapsed() {
      if (!isRunning)
        return false;
      return millis() >= alarmTime;
    }

    bool started() {
      return isRunning;
    }

  private:
    bool isRunning = false;
    unsigned long alarmTime;
};
